library customer;

import 'model.dart';
import 'package:angular2/common.dart';
import 'package:fo_components/fo_components.dart';


class Customer extends Model
{
  Customer();

  @override
  Customer.parse(Map<String, dynamic> data) : super.parse(data)
  {
    belongsTo = data["belongs_to"];
    city = data["city"];
    commentsExternal = data["comments_external"];
    commentsInternal = data["comments_internal"];
    consultationId = data["consultation_id"];
    country = data["country"];
    email = data["email"];
    emailShop = data["email_shop"];
    firstname = data["firstname"];
    lastname = data["lastname"];
    phone = data["phone"];
    postalCode = data["postal_code"];
    preferredLanguage = data["preferred_language"];
    skinType = data["skin_type"];
    socialNumber = data["social_number"];
    street = data["street"];
  }

  @override
  Map<String, dynamic> get properties
  {
    Map<String, dynamic> data = super.properties;
    data["belongs_to"] = belongsTo;
    data["city"] = city;
    data["comments_external"] = commentsExternal;
    data["comments_internal"] = commentsInternal;
    data["consultation_id"] = consultationId;
    data["country"] = country;
    data["email"] = email;
    data["email_shop"] = emailShop;
    data["firstname"] = firstname;
    data["lastname"] = lastname;
    data["phone"] = phone;
    data["postal_code"] = postalCode;
    data["preferred_language"] = preferredLanguage;
    data["skin_type"] = skinType;
    data["social_number"] = socialNumber;
    data["street"] = street;
    return data;
  }

  @override
  List<String> get uniqueFields => ["email", "email_shop", "phone", "social_number"];

  static Map<String, dynamic> get controlsConfig => _controlsConfig;

  static Map<String, dynamic> _controlsConfig =
  {
    "email":[null, Validators.compose([Validators.required, Validators.maxLength(100)])],
    "phone":[null, Validators.compose([Validators.required, FoValidators.isPhoneNumber, Validators.maxLength(32)])],
    "social_number":[null, Validators.compose([Validators.required, Validators.minLength(12), Validators.maxLength(12), FoValidators.isNumeric])],
    "firstname":[null, Validators.compose([Validators.required, FoValidators.isName, Validators.maxLength(64)])],
    "lastname":[null, Validators.compose([Validators.required, FoValidators.isName, Validators.maxLength(64)])],
    "street":[null, Validators.compose([Validators.required, Validators.minLength(4), Validators.maxLength(64)])],
    "postal_code":[null, Validators.compose([Validators.required, FoValidators.isAlphaNumeric, Validators.minLength(2), Validators.maxLength(20)])],
    "city":[null, Validators.compose([Validators.required, Validators.maxLength(64)])],
    "comments_internal" : [null, Validators.maxLength(8000)],
    "comments_external" : [null, Validators.maxLength(8000)],
    "country" : ["sv", Validators.required],
    "skin_type" : ["acne", Validators.required],
    "belongs_to" : [null, Validators.required],
    "status" : ["active", Validators.required],
    "password" : [null, Validators.compose([Validators.required, Validators.minLength(6), Validators.maxLength(64)])],
    "send_email" : [true]
  };


  String belongsTo;
  String commentsExternal;
  String commentsInternal;
  String consultationId;
  String city;
  String country;
  String email;
  String emailShop;
  String firstname;
  String lastname;
  String phone;
  String postalCode;
  String preferredLanguage = "sv";
  String skinType;
  String socialNumber;
  String street;
}